!function(){"use strict";var e={999:function(e,t,r){r.r(t)},335:function(){var e;(e=document.querySelectorAll(".twemoji>svg"))&&0!=e.length&&e.forEach((function(e){var t=document.createElement("img"),r=window.getComputedStyle(e).color||"#333";e.setAttribute("style","fill:"+r+";");var o=(new XMLSerializer).serializeToString(e),n="data:image/svg+xml;base64,"+window.btoa(o);t.setAttribute("src",n),e.parentNode.replaceChild(t,e)}))},680:function(e,t,r){r(335),r(999)}},t={};function r(o){if(t[o])return t[o].exports;var n=t[o]={exports:{}};return e[o](n,n.exports,r),n.exports}r.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},r(680)}();
//# sourceMappingURL=material-polyfills.js.map