<article id="doc-cover">
    {% if cover_logo is defined %}
        <div class="wrapper upper">
            <div class="logo" style="background-image: url({{ cover_logo | to_url }});"></div>
        </div>
    {% else %}
        <div class="wrapper"></div>
    {% endif %}
    <div class="wrapper">
        <h1>{{ cover_title | e }}</h1>
        <h2>{{ cover_subtitle | e }}</h2>
    </div>
    <div class="properties">
        <address>
            {% if author is defined %}
                <p id="author">{{ author | e }}</p>
            {% endif %}
            {% if copyright is defined %}
                <p id="copyright">{{ copyright | e }}</p>
            {% endif %}
        </address>
    </div>
</article>
